==> libunistring_1.0.orig.tar.xz: libunistring-1.0/lib/unicase/u32-is-invariant.c <==
/* Test whether an UTF-32 string is invariant under a given case mapping.
   Copyright (C) 2009-2022 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2009.

   This file is free software.
   It is dual-licensed under "the GNU LGPLv3+ or the GNU GPLv2+".
   You can redistribute it and/or modify it under either
     - the terms of the GNU Lesser General Public License as published
       by the Free Software Foundation; either version 3, or (at your
       option) any later version, or
     - the terms of the GNU General Public License as published by the
       Free Software Foundation; either version 2, or (at your option)
       any later version, or
     - the same dual license "the GNU LGPLv3+ or the GNU GPLv2+".

   This file is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License and the GNU General Public License
   for more details.

   You should have received a copy of the GNU Lesser General Public
   License and of the GNU General Public License along with this
   program.  If not, see <https://www.gnu.org/licenses/>.  */

#include <config.h>

/* Specification.  */
#include "unicase/invariant.h"

#include <errno.h>
#include <stdbool.h>
#include <stdlib.h>

#include "uninorm.h"
#include "unistr.h"

#define FUNC u32_is_invariant
#define UNIT uint32_t
#define U_NORMALIZE u32_normalize
#define U_CMP u32_cmp
#include "u-is-invariant.h"

==> libunistring_1.1.orig.tar.xz: libunistring-1.1/lib/unicase/u32-is-invariant.c <==
/* Test whether an UTF-32 string is invariant under a given case mapping.
   Copyright (C) 2009-2022 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2009.

   This file is free software.
   It is dual-licensed under "the GNU LGPLv3+ or the GNU GPLv2+".
   You can redistribute it and/or modify it under either
     - the terms of the GNU Lesser General Public License as published
       by the Free Software Foundation, either version 3, or (at your
       option) any later version, or
     - the terms of the GNU General Public License as published by the
       Free Software Foundation; either version 2, or (at your option)
       any later version, or
     - the same dual license "the GNU LGPLv3+ or the GNU GPLv2+".

   This file is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License and the GNU General Public License
   for more details.

   You should have received a copy of the GNU Lesser General Public
   License and of the GNU General Public License along with this
   program.  If not, see <https://www.gnu.org/licenses/>.  */

#include <config.h>

/* Specification.  */
#include "unicase/invariant.h"

#include <errno.h>
#include <stdlib.h>

#include "uninorm.h"
#include "unistr.h"

#define FUNC u32_is_invariant
#define UNIT uint32_t
#define U_NORMALIZE u32_normalize
#define U_CMP u32_cmp
#include "u-is-invariant.h"
